@@ -1,22 +1,14 @@
 package WWW::Slides::Controller::Single;
 {
 
-   use version; our $VERSION = qv('0.0.8');
+   use version; our $VERSION = qv('0.0.9');
 
    use warnings;
    use strict;
    use Carp;
    use English qw( -no_match_vars );
 
-   use Object::InsideOut;
-
-   # Other recommended modules (uncomment to use):
-   #  use IO::Prompt;
-   #  use Perl6::Export;
-   #  use Perl6::Slurp;
-   #  use Perl6::Say;
-   #  use Regexp::Autoflags;
-   #  use Readonly;
+   use Object::InsideOut qw( WWW::Slides::Controller );
 
    # Module implementation here
    my @in_handle : Field    # controller handle
@@ -24,30 +16,26 @@ package WWW::Slides::Controller::Single;
      : Arg(Name => 'in_handle', Mandatory => 1);
    my @out_handle : Field : Std(Name => 'out_handle', Private => 1)
      : Arg(Name => 'out_handle');
-   my @buffer : Field : Std(Name => 'buffer', Private => 1);
-   my @selector : Field # For selector handling...
-      : Set(Name => '_set_selector', Private => 1)
-      : Get(Name => 'selector');
 
-   my %init_args : InitArgs = (
-      selector => '',
-   );
-
-   sub _init : Init {
+   sub is_alive {
       my $self = shift;
-      my ($args) = @_;
-      
-      $self->set_buffer('');
-      $self->set_selector($args->{selector}) if $args->{selector};
+      return defined($self->get_in_handle());
+   }
 
+   sub shut_down {
+      my $self = shift;
+      $self->release_selector() if $self->selector();
+      $self->get_in_handle()->close() if $self->get_in_handle();
+      $self->set_in_handle(undef);
+      $self->get_out_handle()->close() if $self->get_out_handle();
+      $self->set_out_handle(undef);
       return;
    }
 
    sub set_selector {
       my ($self, $selector) = @_;
-      return unless $self->is_alive();
-      $selector->add($self->get_in_handle());
-      $self->_set_selector($selector);
+      $selector->add($self->get_in_handle()) if $self->is_alive();
+      $self->SUPER::set_selector($selector);
       return;
    }
 
@@ -55,6 +43,7 @@ package WWW::Slides::Controller::Single;
       my $self = shift;
       return unless $self->is_alive();
       $self->selector()->remove($self->get_in_handle());
+      return;
    }
 
    sub owns {
@@ -67,189 +56,19 @@ package WWW::Slides::Controller::Single;
 
    sub output {
       my $self = shift;
-      my $fh = $self->get_out_handle()
-         or croak 'object is not alive, no output possible';
+      croak 'object is not alive, no output possible'
+         unless $self->is_alive();
+      my $fh = $self->get_out_handle() or return;
       print {$fh} @_;
       return;
    }
 
-   #-------------- COMMAND EXECUTION FRAMEWORK -------------------------
-   my %commands = (
-      'nothing' => sub {
-         print "nothing\n";
-      },
-
-      # Slide transition management
-      'first' => sub {
-         my $self = shift;
-         my ($command, $talk) = @_;
-         $talk->show_first(@{$command->{target}});
-         $self->output("200 OK\n");
-      },
-      'last' => sub {
-         my $self = shift;
-         my ($command, $talk) = @_;
-         $talk->show_last(@{$command->{target}});
-         $self->output("200 OK\n");
-      },
-      'next' => sub {
-         my $self = shift;
-         my ($command, $talk) = @_;
-         $talk->show_next(@{$command->{target}});
-         $self->output("200 OK\n");
-      },
-      'previous' => sub {
-         my $self = shift;
-         my ($command, $talk) = @_;
-         $talk->show_previous(@{$command->{target}});
-         $self->output("200 OK\n");
-      },
-      'show' => sub {
-         my ($self, $command, $talk) = @_;
-         $talk->show($command->{slide}, @{$command->{target}});
-         $self->output("200 OK\n");
-      },
-
-      
-      # Attendee management
-      'book' => sub {
-         my $self = shift;
-         my ($command, $talk) = @_;
-         $talk->book($command->{code});
-         $self->output("200 OK\n");
-      },
-      'attach' => sub {
-         my ($self, $command, $talk) = @_;
-         $talk->attach(@{ $command->{target} });
-         $self->output("200 OK\n");
-      },
-      'detach' => sub {
-         my ($self, $command, $talk) = @_;
-         $talk->detach(@{ $command->{target} });
-         $self->output("200 OK\n");
-      },
-      'clamp' => sub {
-         my ($self, $command, $talk) = @_;
-         $talk->clamp();
-         $self->output("200 OK\n");
-      },
-      'loose' => sub {
-         my ($self, $command, $talk) = @_;
-         $talk->loose();
-         $self->output("200 OK\n");
-      },
-
-      # Requests from far
-      'get_current' => sub {
-         my ($self, $command, $talk) = @_;
-         my $current = $talk->get_current();
-         my $total   = $talk->get_total();
-         $self->output("200 OK current=$current;total=$total\n");
-      },
-
-      'get_attendees' => sub {
-         my ($self, $command, $talk) = @_;
-         my $output = join "\n", map {
-            my @elements;
-            while (my ($k, $v) = each %$_) {
-               $v = '' unless defined $v;
-               push @elements, "$k=$v";
-            }
-            join ';', @elements;
-         } $talk->get_attendees_details();
-         $self->output("200 OK\n$output\n");
-      },
-      
-      # Ehr... quit
-      'quit' => sub {
-         my $self = shift;
-         my ($command, $talk) = @_;
-         $talk->quit();
-         $self->output("200 OK\n");
-      },
-   );
-
-   sub execute_command {
+   sub get_input_chunk {
       my $self = shift;
-      my ($command, $talk) = @_;
-
-      my $cmd = $command->{command};
-      $cmd = '' unless defined $cmd;
-      if (exists $commands{$cmd}) {
-         eval {
-            $commands{$cmd}->($self, $command, $talk);
-         };
-         if ($EVAL_ERROR) {
-            $self->output("500 error executing '$cmd': $EVAL_ERROR\n");
-         }
-      }
-      else {
-         $self->output("500 command '$cmd' not supported\n");
-      }
-      
-      return;
-   }
-
-   sub execute_commands {
-      my $self = shift;
-      my ($fh, $talk) = @_;
-
-      # Execute each command
-      $self->execute_command($_, $talk) for $self->get_commands();
-
-      return;
-   } ## end sub execute_commands
-   #--------------------------------------------------------------------
-
-   sub parse_command {
-      my $self = shift;
-      my ($command_string) = @_;
-      my $command = {
-         map {
-            my ($k, $v) = split /=/;
-            $v = '' unless defined $v;
-            $k => $v;
-           } split /[\s;]+/,
-         $command_string
-      };
-      $command->{target} =
-         defined($command->{target})
-         ? [ split /,/, $command->{target} ]
-         : [];
-      return $command;
-   } ## end sub parse_command
-
-   sub shut_down {
-      my $self = shift;
-      $self->release_selector() if $self->selector();
-      $self->get_in_handle()->close() if $self->get_in_handle();
-      $self->set_in_handle(undef);
-      $self->get_out_handle()->close() if $self->get_out_handle();
-      $self->set_out_handle(undef);
-      return;
-   }
-
-   sub get_commands {
-      my $self       = shift;
-
-      # Get new stuff from filehandle, extract full commands
-      $self->get_in_handle()->sysread(my $newstuff, 1024);
-      my $buffer = $self->get_buffer() . $newstuff;
-      my @full_lines = split /\n/, $buffer;
-      my $remaining  = '';
-      $remaining = pop @full_lines unless substr($buffer, -1) eq "\n";
-      $self->set_buffer($remaining);
-
-      # Shut this controller off if received EOF
-      $self->shut_down unless length $newstuff;
-
-      # Return parsed commands
-      return map { $self->parse_command($_) } @full_lines;
-   } ## end sub parse_commands
-
-   sub is_alive {
-      my $self = shift;
-      return defined($self->get_in_handle());
+      croak 'not alive, cannot input' unless $self->is_alive();
+      $self->get_in_handle()->sysread(my $newstuff, 4096);
+      return unless defined $newstuff and length $newstuff;
+      return $newstuff;
    }
 }
 
@@ -263,7 +82,7 @@ WWW::Slides::Controller::Single - main base class for controllers based in I/O
 
 =head1 VERSION
 
-This document describes WWW::Slides::Controller::Single version 0.0.8
+This document describes WWW::Slides::Controller::Single version 0.0.9
 
 
 =head1 SYNOPSIS
